import React from 'react';
import { MatrixClient } from 'matrix-js-sdk/src/client';
import { MatrixCall } from 'matrix-js-sdk/src/webrtc/call';
import { IMatrixClientCreds } from '../../MatrixClientPeg';
import { Resizer } from '../../resizer';
import ResizeNotifier from "../../utils/ResizeNotifier";
import { IOOBData, IThreepidInvite } from "../../stores/ThreepidInviteStore";
import { IOpts } from "../../createRoom";
export declare function getInputableElement(el: HTMLElement): HTMLElement | null;
interface IProps {
    matrixClient: MatrixClient;
    onRegistered: (credentials: IMatrixClientCreds) => Promise<MatrixClient>;
    hideToSRUsers: boolean;
    resizeNotifier: ResizeNotifier;
    page_type?: string;
    autoJoin?: boolean;
    threepidInvite?: IThreepidInvite;
    roomOobData?: IOOBData;
    currentRoomId: string;
    collapseLhs: boolean;
    config: {
        piwik: {
            policyUrl: string;
        };
        [key: string]: any;
    };
    currentUserId?: string;
    currentGroupId?: string;
    currentGroupIsNew?: boolean;
    justRegistered?: boolean;
    roomJustCreatedOpts?: IOpts;
    forceTimeline?: boolean;
}
interface IUsageLimit {
    limit_type: "monthly_active_user" | "hs_disabled" | string;
    admin_contact?: string;
}
interface IState {
    syncErrorData?: {
        error: {
            data: IUsageLimit;
            errcode: string;
        };
    };
    usageLimitDismissed: boolean;
    usageLimitEventContent?: IUsageLimit;
    usageLimitEventTs?: number;
    useCompactLayout: boolean;
    activeCalls: Array<MatrixCall>;
    backgroundImage?: string;
}
/**
 * This is what our MatrixChat shows when we are logged in. The precise view is
 * determined by the page_type property.
 *
 * Currently, it's very tightly coupled with MatrixChat. We should try to do
 * something about that.
 *
 * Components mounted below us can access the matrix client via the react context.
 */
declare class LoggedInView extends React.Component<IProps, IState> {
    static displayName: string;
    protected readonly _matrixClient: MatrixClient;
    protected readonly _roomView: React.RefObject<any>;
    protected readonly _resizeContainer: React.RefObject<HTMLDivElement>;
    protected readonly resizeHandler: React.RefObject<HTMLDivElement>;
    protected compactLayoutWatcherRef: string;
    protected backgroundImageWatcherRef: string;
    protected resizer: Resizer;
    constructor(props: any, context: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    private onCallState;
    private refreshBackgroundImage;
    canResetTimelineInRoom: (roomId: string) => any;
    private createResizer;
    private loadResizerPreferences;
    private onAccountData;
    onCompactLayoutChanged: (setting: any, roomId: any, level: any, valueAtLevel: any, newValue: any) => void;
    onSync: (syncState: any, oldSyncState: any, data: any) => void;
    onRoomStateEvents: (ev: any, state: any) => void;
    private onUsageLimitDismissed;
    private calculateServerLimitToast;
    private updateServerNoticeEvents;
    private onPaste;
    private onReactKeyDown;
    private onNativeKeyDown;
    private onKeyDown;
    /**
     * dispatch a page-up/page-down/etc to the appropriate component
     * @param {Object} ev The key event
     */
    private onScrollKeyPressed;
    render(): JSX.Element;
}
export default LoggedInView;
